SQLAlchemy 0.3 Documentation - module sqlalchemy.databases.oracle

# SQLAlchemy 0.3 Documentation

Multiple Pages | One Page
Version: 0.3.10 Last Updated: 07/20/07 17:20:04

### module sqlalchemy.databases.oracle

### Module Functions

def descriptor()

### class OracleBinary(Binary)

def convert_bind_param(self, value, dialect)
def convert_result_value(self, value, dialect)
def get_col_spec(self)
def get_dbapi_type(self, dbapi)
back to section top

### class OracleBoolean(Boolean)

def convert_bind_param(self, value, dialect)
def convert_result_value(self, value, dialect)
def get_col_spec(self)
back to section top

### class OracleChar(CHAR)

def get_col_spec(self)
back to section top

### class OracleCompiler(ANSICompiler)

Oracle compiler modifies the lexical structure of Select statements to work under non-ANSI configured Oracle databases, if the use_ansi flag is False.

def __init__(self, *args, **kwargs)
def apply_function_parens(self, func)
def default_from(self)

Called when a `SELECT` statement has no froms, and no `FROM` clause is to be appended.

The Oracle compiler tacks a "FROM DUAL" to the statement.

def for_update_clause(self, select)
def limit_clause(self, select)
def visit_alias(self, alias)

Oracle doesn't like `FROM table AS alias`. Is the AS standard SQL??

def visit_binary(self, binary)
def visit_column(self, column)
def visit_insert(self, insert)

`INSERT` s are required to have the primary keys be explicitly present.

Mapper will by default not put them in the insert statement to comply with autoincrement fields that require they not be present. so, put them all in for all primary key columns.

def visit_insert_sequence(self, column, sequence, parameters)

This is the sequence equivalent to `ANSICompiler`'s visit_insert_column_default which ensures that the column is present in the generated column list.

def visit_join(self, join)
def visit_select(self, select)

Look for `LIMIT` and OFFSET in a select statement, and if so tries to wrap it in a subquery with `row_number()` criterion.

back to section top

### class OracleDate(Date)

def convert_bind_param(self, value, dialect)
def convert_result_value(self, value, dialect)
def get_col_spec(self)
back to section top

### class OracleDateTime(DateTime)

def convert_result_value(self, value, dialect)
def get_col_spec(self)
back to section top

### class OracleDefaultRunner(ANSIDefaultRunner)

def exec_default_sql(self, default)
def visit_sequence(self, seq)
back to section top

### class OracleDialect(ANSIDialect)

def __init__(self, use_ansi=True, auto_setinputsizes=True, auto_convert_lobs=True, threaded=True, **kwargs)
def compiler(self, statement, bindparams, **kwargs)
def create_connect_args(self, url)
def create_execution_context(self, *args, **kwargs)
def dbapi(cls)
def defaultrunner(self, connection, **kwargs)
def do_executemany(self, c, statement, parameters, context=None)
def has_sequence(self, connection, sequence_name)
def has_table(self, connection, table_name, schema=None)
def max_identifier_length(self)
def oid_column_name(self, column)
def reflecttable(self, connection, table)
def schemadropper(self, *args, **kwargs)
def schemagenerator(self, *args, **kwargs)
def supports_unicode_statements(self)

indicate whether the DBAPI can receive SQL statements as Python unicode strings

def type_descriptor(self, typeobj)
back to section top

### class OracleExecutionContext(DefaultExecutionContext)

def get_result_proxy(self)
def pre_exec(self)
back to section top

### class OracleInteger(Integer)

def get_col_spec(self)
back to section top

### class OracleNumeric(Numeric)

def get_col_spec(self)
back to section top

### class OracleRaw(Binary)

def get_col_spec(self)
back to section top

### class OracleSchemaDropper(ANSISchemaDropper)

def visit_sequence(self, sequence)
back to section top

### class OracleSchemaGenerator(ANSISchemaGenerator)

def get_column_specification(self, column, **kwargs)
def visit_sequence(self, sequence)
back to section top

### class OracleSmallInteger(SmallInteger)

def get_col_spec(self)
back to section top

### class OracleString(String)

def get_col_spec(self)
back to section top

### class OracleText(TEXT)

def convert_result_value(self, value, dialect)
def get_col_spec(self)
def get_dbapi_type(self, dbapi)
back to section top

### class OracleTimestamp(TIMESTAMP)

def convert_result_value(self, value, dialect)
def get_col_spec(self)
def get_dbapi_type(self, dialect)
back to section top